@@ -31,6 +31,7 @@ UNVERSIONED_INPUTS_ROOT = Path('/ihme/covid-19/unversioned-inputs')
 STATIC_DATA_INPUTS_ROOT = Path('/ihme/covid-19/static-data')
 SNAPSHOT_ROOT = Path('/ihme/covid-19/snapshot-data/')
 MODEL_INPUTS_ROOT = Path('/ihme/covid-19/model-inputs/')
+VISIT_VOLUME_ROOT = Path('/ihme/covid-19/visit-volume/')
 DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
 INFECTIONATOR_OUTPUTS = Path('/ihme/covid-19/seir-inputs')
 SHAPEFILE_ROOT = Path('/ihme/covid-19/shapefiles')
@@ -48,6 +49,7 @@ SEIR_COVARIATES_OUTPUT_ROOT = Path('/ihme/covid-19/seir-covariates')
 SEIR_REGRESSION_OUTPUTS = Path('/ihme/covid-19/seir-regression')
 SEIR_FORECAST_OUTPUTS = Path('/ihme/covid-19/seir-forecast')
 SEIR_FINAL_OUTPUTS = Path('/ihme/covid-19/seir-outputs')
+SEIR_DIAGNOSTICS_OUTPUTS = Path('/ihme/covid-19/seir-diagnostics')
 
 
 # Shared file names
